@@ -123,8 +123,8 @@ pub fn router<DB: Database>(database: DB, settings: Settings) -> Router {
         .route("/account/password", patch(handlers::user::change_password))
         .route("/register", post(handlers::user::register))
         .route("/login", post(handlers::user::login))
-        .route("/record", post(handlers::record::post::<DB>))
-        .route("/record", get(handlers::record::index::<DB>))
+        .route("/record", post(handlers::record::post))
+        .route("/record", get(handlers::record::index))
         .route("/record/next", get(handlers::record::next))
         .route("/api/v0/me", get(handlers::v0::me::get))
         .route("/api/v0/account/verify", post(handlers::user::verify_user))
