@@ -3,15 +3,13 @@ use std::path::PathBuf;
 use crate::{SHA, VERSION};
 use atuin_client::{api_client, database::Database, settings::Settings};
 use colored::Colorize;
-use eyre::Result;
+use eyre::{Result, bail};
 
 pub async fn run(settings: &Settings, db: &impl Database) -> Result<()> {
     let session_path = settings.session_path.as_str();
 
     if !PathBuf::from(session_path).exists() {
-        println!("You are not logged in to a sync server - cannot show sync status");
-
-        return Ok(());
+        bail!("You are not logged in to a sync server - cannot show sync status");
     }
 
     let client = api_client::Client::new(
@@ -30,7 +28,7 @@ pub async fn run(settings: &Settings, db: &impl Database) -> Result<()> {
 
     if settings.auto_sync {
         println!("Sync frequency: {}", settings.sync_frequency);
-        println!("Last sync: {last_sync}");
+        println!("Last sync: {}", last_sync.to_offset(settings.timezone.0));
     }
 
     if !settings.sync.records {
